Learn R Programming

nCal (version 13.12-01)

hier.model.ex.2: An example for hierarchical modeling used in Fong, Yu et al.

Description

An example for hierarchical modeling used in Fong, Yu et al.

Arguments

References

Fong, Y., Yu, X., Sebestyen, K., Gilbert, P. and Self, S. (2013) nCal: a R package for nonlinear calibration. Submitted.